widgets library

PTY widgets for package:artisanal_widgets.

Also exports the transport-independent terminal model and input encoder so widget applications normally need only this import.

Classes

PseudoTerminalView
Placeholder on platforms where dart:io PTYs are unavailable.
TerminalInputEncoder
Encodes Artisanal key events as terminal input.
TerminalView
Displays a VirtualTerminal and forwards focused keyboard input.
VirtualTerminal
A small, transport-independent ANSI/VT screen model.

Enums

TerminalMouseTracking
Mouse event reporting requested by the hosted terminal application.